@@ -5,25 +5,20 @@ exception Unseeded_generator
 exception No_default_generator
 
 let setup_rng =
-  "\nTo initialize the RNG with a default generator, and set up entropy \
+  "\nPlease setup your default random number generator. On Unix, the best \
+   path is to call [Mirage_crypto_rng_unix.use_default ()].\
+   \nBut you can use Fortuna (or any other RNG) and setup the seeding \
+   (done by default in MirageOS): \
+   \n\
+   \nTo initialize the RNG with a default generator, and set up entropy \
    collection and periodic reseeding as a background task, do the \
    following:\
    \n  If you are using MirageOS, use the random device in config.ml: \
    `let main = Mirage.main \"Unikernel.Main\" (random @-> job)`, \
    and `let () = register \"my_unikernel\" [main $ default_random]`. \
-   \n  If you are using Lwt, execute \
-   `Mirage_crypto_rng_lwt.initialize (module Mirage_crypto_rng.Fortuna)` \
-   at startup. \
-   \n  If you are using Async, execute \
-   `Mirage_crypto_rng_async.initialize (module Mirage_crypto_rng.Fortuna)` \
-   at startup. \
-   \n  If you are using Eio, execute in one of the fibers \
-   `Mirage_crypto_rng_eio.run (module Fortuna) env` (`env` from `Eio_main.run`).
-   \n  Otherwise, there is no periodic reseeding. For an initial seed from \
-   getrandom(), execute \
-   `Mirage_crypto_rng_unix.initialize (module Mirage_crypto_rng.Fortuna)`. \
-   You can use `Mirage_crypto_rng.accumulate` and `Mirage_crypto_rng.reseed` \
-   to reseed the RNG manually."
+   \n  If you are using miou, execute \
+   `Mirage_crypto_rng_miou_unix.initialize (module Mirage_crypto_rng.Fortuna)` \
+   at startup."
 
 let () = Printexc.register_printer (function
     | Unseeded_generator ->
@@ -37,6 +32,7 @@ module type Generator = sig
   val block : int
   val create : ?time:(unit -> int64) -> unit -> g
   val generate_into : g:g -> bytes -> off:int -> int -> unit
+  [@@alert unsafe "Does not do bounds checks. Use Mirage_crypto_rng.generate_into instead."]
   val reseed : g:g -> string -> unit
   val accumulate : g:g -> source -> [`Acc of string -> unit]
   val seeded : g:g -> bool
@@ -68,9 +64,14 @@ let get = function Some g -> g | None -> default_generator ()
 let generate_into ?(g = default_generator ()) b ?(off = 0) n =
   let Generator (g, _, m) = g in
   let module M = (val m) in
+  if off < 0 || n < 0 then
+    invalid_arg ("negative offset " ^ string_of_int off ^ " or length " ^
+                 string_of_int n);
   if Bytes.length b - off < n then
     invalid_arg "buffer too short";
-  M.generate_into ~g b ~off n
+  begin[@alert "-unsafe"]
+    M.generate_into ~g b ~off n
+  end
 
 let generate ?g n =
   let data = Bytes.create n in
